pub enum HeaderExtError {
Chain(Box<dyn Error + Send + Sync>),
BlockNotFound,
ChainWorkOverflow,
}Expand description
Errors that can occur when using the HeaderExt methods.
Variants
Chain(Box<dyn Error + Send + Sync>)
An error related to the blockchain interface, wrapping the actual error.
BlockNotFound
Indicates that the block could not be found in the blockchain.
ChainWorkOverflow
You got an overflow while calculating the chain work.